@@ -986,6 +986,7 @@ def prefixed_command(
     *,
     aliases: typing.Optional[typing.List[str]] = None,
     help: typing.Optional[str] = None,
+    description: typing.Optional[str] = None,
     brief: typing.Optional[str] = None,
     usage: typing.Optional[str] = None,
     enabled: bool = True,
@@ -1004,6 +1005,7 @@ def prefixed_command(
         aliases: The list of aliases the command can be invoked under.
         help: The long help text for the command. \
             Defaults to the docstring of the coroutine, if there is one.
+        description: An alias for ``help`` - ``help`` will take presidence over it.
         brief: The short help text for the command. \
             Defaults to the first line of the help text, if there is one.
         usage: A string displaying how the command can be used. If no \
@@ -1034,7 +1036,7 @@ def prefixed_command(
             callback=func,
             name=name or func.__name__,
             aliases=aliases or [],
-            help=help,
+            help=help or description,
             brief=brief,
             usage=usage,  # type: ignore
             enabled=enabled,
@@ -1062,7 +1064,7 @@ MCT = typing.TypeVar("MCT", typing.Callable, MolterCommand)
 
 def register_converter(
     type_: type, converter: typing.Type[converters.MolterConverter]
-) -> typing.Callable[..., MCT]:
+) -> typing.Callable[[MCT], MCT]:
     """
     A decorator that allows you to register converters for a type for a specific command.
     This allows for native type annotations without needing to use ``typing(_extensions).Annotated``.
@@ -1107,7 +1109,7 @@ def globally_register_converter(
 
     # hate me, but i think it makes sense here
     global _global_type_to_converter
-    _global_type_to_converter.update({anno_type: converter})
+    _global_type_to_converter.update({anno_type: converter})  # type: ignore
 
 
 def prefixed_parameter(
@@ -1117,7 +1119,7 @@ def prefixed_parameter(
     factory: typing.Optional[
         typing.Callable[[context.MolterContext], typing.Any]
     ] = None,
-) -> typing.Callable[..., MCT]:
+) -> typing.Callable[[MCT], MCT]:
     """
     A decorator that allows you to adjust a parameter in a prefixed command.
 
