@@ -49,8 +49,10 @@ class CheckFailure(MolterException):
         context: "MolterContext",
         message: typing.Optional[str] = "A check has failed.",
         *,
-        check: typing.Callable[
-            ["MolterContext"], typing.Coroutine[typing.Any, typing.Any, bool]
+        check: typing.Optional[
+            typing.Callable[
+                ["MolterContext"], typing.Coroutine[typing.Any, typing.Any, bool]
+            ]
         ] = None,
     ):
         self.context = context
