@@ -74,7 +74,7 @@ class MolterManager:
             # by default, use mentioning the bot as the prefix
             generate_prefixes = utils.when_mentioned
 
-        elif not interactions.Intents.GUILD_MESSAGE_CONTENT in self.client._intents:
+        elif interactions.Intents.GUILD_MESSAGE_CONTENT not in self.client._intents:
             # sanity check
             logger.warning(
                 "The GUILD_MESSAGE_CONTENT is not enabled! This is required for"
@@ -110,14 +110,14 @@ class MolterManager:
         # after the bot has started, to which they should be using add_prefixed_command
         # anyways.
         def cursed_override(old_ready):
-            async def new_ready():
+            async def new_ready(*args, **kwargs):
                 for _, func in inspect.getmembers(
                     sys.modules["__main__"],
                     predicate=lambda x: isinstance(x, MolterCommand)
                     and not x.is_subcommand(),
                 ):
                     self.add_prefixed_command(func)
-                await old_ready()
+                await old_ready(*args, **kwargs)
 
             return new_ready
 
